@@ -1,5 +1,6 @@
 """Module for Maximum Likelihood Estimation."""
 from .. import get_backend
+from ..exceptions import UnspecifiedPOI
 
 
 def twice_nll(pars, data, pdf):
@@ -21,6 +22,12 @@ def fit(data, pdf, init_pars=None, par_bounds=None, **kwargs):
     """
     Run a unconstrained maximum likelihood fit.
 
+    .. note::
+
+        :func:`twice_nll` is the objective function given to the optimizer and
+        is returned evaluated at the best fit model parameters when the optional
+        kwarg ``return_fitted_val`` is ``True``.
+
     Example:
         >>> import pyhf
         >>> pyhf.set_backend("numpy")
@@ -29,8 +36,13 @@ def fit(data, pdf, init_pars=None, par_bounds=None, **kwargs):
         ... )
         >>> observations = [51, 48]
         >>> data = pyhf.tensorlib.astensor(observations + model.config.auxdata)
-        >>> pyhf.infer.mle.fit(data, model, return_fitted_val=True)
-        (array([0.        , 1.0030512 , 0.96266961]), array([24.98393521]))
+        >>> bestfit_pars, twice_nll = pyhf.infer.mle.fit(data, model, return_fitted_val=True)
+        >>> bestfit_pars
+        array([0.        , 1.0030512 , 0.96266961])
+        >>> twice_nll
+        array(24.98393521)
+        >>> -2 * model.logpdf(bestfit_pars, data) == twice_nll
+        array([ True])
 
     Args:
         data (`tensor`): The data
@@ -53,6 +65,12 @@ def fixed_poi_fit(poi_val, data, pdf, init_pars=None, par_bounds=None, **kwargs)
     """
     Run a maximum likelihood fit with the POI value fixed.
 
+    .. note::
+
+        :func:`twice_nll` is the objective function given to the optimizer and
+        is returned evaluated at the best fit model parameters when the optional
+        kwarg ``return_fitted_val`` is ``True``.
+
     Example:
         >>> import pyhf
         >>> pyhf.set_backend("numpy")
@@ -62,8 +80,15 @@ def fixed_poi_fit(poi_val, data, pdf, init_pars=None, par_bounds=None, **kwargs)
         >>> observations = [51, 48]
         >>> data = pyhf.tensorlib.astensor(observations + model.config.auxdata)
         >>> test_poi = 1.0
-        >>> pyhf.infer.mle.fixed_poi_fit(test_poi, data, model, return_fitted_val=True)
-        (array([1.        , 0.97224597, 0.87553894]), array([28.92218013]))
+        >>> bestfit_pars, twice_nll = pyhf.infer.mle.fixed_poi_fit(
+        ...     test_poi, data, model, return_fitted_val=True
+        ... )
+        >>> bestfit_pars
+        array([1.        , 0.97224597, 0.87553894])
+        >>> twice_nll
+        array(28.92218013)
+        >>> -2 * model.logpdf(bestfit_pars, data) == twice_nll
+        array([ True])
 
     Args:
         data: The data
@@ -76,6 +101,10 @@ def fixed_poi_fit(poi_val, data, pdf, init_pars=None, par_bounds=None, **kwargs)
         See optimizer API
 
     """
+    if pdf.config.poi_index is None:
+        raise UnspecifiedPOI(
+            'No POI is defined. A POI is required to fit with a fixed POI.'
+        )
     _, opt = get_backend()
     init_pars = init_pars or pdf.config.suggested_init()
     par_bounds = par_bounds or pdf.config.suggested_bounds()
