@@ -9,15 +9,22 @@ log = logging.getLogger(__name__)
 class tensorflow_backend(object):
     """TensorFlow backend for pyhf"""
 
+    __slots__ = ['name', 'precision', 'dtypemap', 'default_do_grad']
+
     def __init__(self, **kwargs):
         self.name = 'tensorflow'
+        self.precision = kwargs.get('precision', '32b')
         self.dtypemap = {
-            'float': getattr(tf, kwargs.get('float', 'float32')),
-            'int': getattr(tf, kwargs.get('int', 'int32')),
+            'float': tf.float64 if self.precision == '64b' else tf.float32,
+            'int': tf.int64 if self.precision == '64b' else tf.int32,
             'bool': tf.bool,
         }
-        self.float_precision = '32b' if self.dtypemap['float'] == tf.float32 else '64b'
-        self.int_precision = '32b' if self.dtypemap['int'] == tf.int32 else '64b'
+        self.default_do_grad = True
+
+    def _setup(self):
+        """
+        Run any global setups for the tensorflow lib.
+        """
 
     def clip(self, tensor_in, min_value, max_value):
         """
@@ -129,6 +136,18 @@ class tensorflow_backend(object):
         """
         Convert to a TensorFlow Tensor.
 
+        Example:
+
+            >>> import pyhf
+            >>> pyhf.set_backend("tensorflow")
+            >>> tensor = pyhf.tensorlib.astensor([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0]])
+            >>> tensor
+            <tf.Tensor: shape=(2, 3), dtype=float32, numpy=
+            array([[1., 2., 3.],
+                   [4., 5., 6.]], dtype=float32)>
+            >>> type(tensor)
+            <class 'tensorflow.python.framework.ops.EagerTensor'>
+
         Args:
             tensor_in (Number or Tensor): Tensor object
 
@@ -149,11 +168,6 @@ class tensorflow_backend(object):
             tensor.device
         except AttributeError:
             tensor = tf.convert_to_tensor(tensor_in)
-            # Ensure non-empty tensor shape for consistency
-            try:
-                tensor.shape[0]
-            except IndexError:
-                tensor = tf.reshape(tensor, [1])
         if tensor.dtype is not dtype:
             tensor = tf.cast(tensor, dtype)
         return tensor
@@ -269,22 +283,16 @@ class tensorflow_backend(object):
             list of Tensors: The sequence broadcast together.
 
         """
-        max_dim = max(map(lambda arg: arg.shape[0], args))
+
+        max_dim = max(map(tf.size, args))
         try:
-            assert not [arg for arg in args if 1 < arg.shape[0] < max_dim]
+            assert not [arg for arg in args if 1 < tf.size(arg) < max_dim]
         except AssertionError as error:
             log.error(
                 'ERROR: The arguments must be of compatible size: 1 or %i', max_dim
             )
             raise error
-
-        broadcast = [
-            arg
-            if arg.shape[0] > 1
-            else tf.tile(tf.slice(arg, [0], [1]), tf.stack([max_dim]))
-            for arg in args
-        ]
-        return broadcast
+        return [tf.broadcast_to(arg, (max_dim,)) for arg in args]
 
     def einsum(self, subscripts, *operands):
         """
@@ -445,7 +453,7 @@ class tensorflow_backend(object):
             TensorFlow Tensor: The CDF
         """
         normal = tfp.distributions.Normal(
-            self.astensor(mu, dtype='float')[0], self.astensor(sigma, dtype='float')[0],
+            self.astensor(mu, dtype='float'), self.astensor(sigma, dtype='float'),
         )
         return normal.cdf(x)
 
